@@ -174,8 +174,8 @@ class Lotus:
     def run(self):
         # Main loop
         self.order = BitmexOrder(self.symbols,
-                                 self.client, self.settings, self._settings_path)
-        self.process_signals(start=True)
+                                 self.client, self.settings, self._settings_path)     
+        self.process_signals(self.get_api_signal(), start=True)
         while True:
             time.sleep(10)
             self.order.manage_entries(self.symbols)
